#[non_exhaustive]
pub enum Request { Destroy, WarpPointer { surface: WlSurface, pointer: WlPointer, x: f64, y: f64, serial: u32, }, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Destroy

destroy the warp manager

Destroy the pointer warp manager.

This is a destructor, once received this object cannot be used any longer.



WarpPointer

reposition the pointer

Request the compositor to move the pointer to a surface-local position. Whether or not the compositor honors the request is implementation defined, but it should

  • honor it if the surface has pointer focus, including when it has an implicit pointer grab
  • reject it if the enter serial is incorrect
  • reject it if the requested position is outside of the surface

Note that the enter serial is valid for any surface of the client, and does not have to be from the surface the pointer is warped to.

Fields

surface: WlSurface

surface to position the pointer on

pointer: WlPointer

the pointer that should be repositioned

serial: u32

serial number of the enter event

Implementations



impl Request

pub fn opcode(&self) -> u16

Get the opcode number of this message