Struct WpPointerWarpV1
pub struct WpPointerWarpV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
reposition the pointer to a location on a surface
This global interface allows applications to request the pointer to be moved to a position relative to a wl_surface.
Note that if the desired behavior is to constrain the pointer to an area or lock it to a position, this protocol does not provide a reliable way to do that. The pointer constraint and pointer lock protocols should be used for those use cases instead.
Warning! The protocol described in this file is currently in the testing phase. Backward compatible changes may be added together with the corresponding interface version bump. Backward incompatible changes can only be done by creating a new major version of the extension.
See also the Request enum for this interface.